clear
capture log close
set more off 
set mem 500m


*** Set global here
global root "C:\Users\Walker\Dropbox\Coal_and_city_growth\EJ_replication_files"
global temp "$root\temp"



***** Begin with city-industry data and calculate national industry growth rates dropping one city at a time ****

foreach i in "bath" "birmingham" "blackburn" "bolton" "bradford" "brighton" "bristol" "derby" "gateshead" "halifax" "huddersfield" "hull" "ipswich" "leeds" "leicester" "liverpool" "london" "manchester" "newcastle" "northampton" "norwich" "nottingham" "oldham" "portsmouth" "preston" "sheffield" "south_shields" "southampton" "stockport" "sunderland" "wolverhampton" {

use "$root\input_data\CCG_data_agg_analysis_industries", clear
gen new_loc="`i'"
drop if loc=="`i'"
collapse (sum) pop, by(group_2 year new_loc)


gen pop_lag20=0
sort new_loc group_2 year
replace pop_lag20=pop[_n-2] if new_loc==new_loc[_n-2] & group_2==group_2[_n-2]

gen growth20=pop/pop_lag20

keep group_2 year growth20 new_loc
sort group_2 year
save "$root\temp\national_ind_growth_lag20_`i'_all_ind", replace

}

** Append
use "$root\temp\national_ind_growth_lag20_birmingham_all_ind", clear

foreach i in "bath" "blackburn" "bolton" "bradford" "brighton" "bristol" "derby" "gateshead" "halifax" "huddersfield" "hull" "ipswich" "leeds" "leicester" "liverpool" "london" "manchester" "newcastle" "northampton" "norwich" "nottingham" "oldham" "portsmouth" "preston" "sheffield" "south_shields" "southampton" "stockport" "sunderland" "wolverhampton" {

append using "$root\temp\national_ind_growth_lag20_`i'_all_ind"

}


rename new_loc loc
sort loc group_2 year
save "$root\temp\national_ind_growth_lag20_all_ind", replace




********************** Merge growth rates into main data ***********************
use "$root\input_data\CCG_data_agg_analysis_industries", clear


sort loc group_2 year
merge loc group_2 year using "$root\temp\national_ind_growth_lag20_all_ind"
tab _merge
drop _merge


** Generated predicted employment in each city-industry
gen pop_lag20=0
sort loc group_2 year
replace pop_lag20=pop[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]
gen predicted_pop=pop_lag20*growth20


*** Merge in coal use data and drop non-analysis industries
sort group_2
merge group_2 using "$root\input_data\industry_coal_use"
tab _merge
keep if _merge==3
replace cc_per_worker=0 if cc_per_worker==.


** Coal use variables
replace cc_per_worker=0 if cc_per_worker==.
gen coal_use=pop*cc_per_worker
gen coal_use_iv=predicted_pop*cc_per_worker


** Collapse to city-year level
collapse (sum) pop predicted_pop coal_use coal_use_iv, by(loc year)


** Adjust coal use levels
sort year
merge year using "$root\input_data\coal_use_adjustment_factors"
tab _merge
drop _merge
replace coal_use=coal_use*adjustment_factor
replace coal_use_iv=coal_use_iv*adjustment_factor


*** Actual change in working population in analysis industries
gen logworkpop=ln(pop)
sort loc year
gen chg_log_workpop=logworkpop-logworkpop[_n-2] if loc==loc[_n-2]


*** Predicted change in working population in analysis industries
gen log_predpop=ln(predicted_pop)
sort loc year
gen chg_log_predpop=log_predpop-logworkpop[_n-2] if loc==loc[_n-2]

*** Difference in actual vs. predicted working population growth
gen diff=chg_log_workpop - chg_log_predpop 


*** Change in log coal iv compared to two decades before
gen ln_coal=ln(coal_use)
gen ln_coal_iv=ln(coal_use_iv)
sort loc year
gen chg_ln_coal_use_iv=ln_coal_iv-ln_coal[_n-2] if loc==loc[_n-2]



*** Reshape
keep loc diff chg_ln_coal_use_iv year
reshape wide diff chg_ln_coal_use_iv, i(loc) j(year)


**** Now demean by year
foreach i in 1871 1881 1891 1901 1911 {

egen yr_coal_avg_`i'=mean(chg_ln_coal_use_iv`i')
gen dm_coal_`i'=chg_ln_coal_use_iv`i'-yr_coal_avg_`i'

egen yr_diff_avg_`i'=mean(diff`i')
gen dm_diff_`i'=diff`i'-yr_diff_avg_`i'

}

keep loc dm* 

reshape long dm_diff_ dm_coal_, i(loc) j(year)

outsheet using "$root\Figure_2\Figure_2_data.csv", comma names replace


****
