clear
capture log close
set more off 
set mem 500m

*** Set global here
global root "C:\Users\Walker\Dropbox\Coal_and_city_growth\EJ_replication_files"
global temp "$root\temp"



***** Begin with city-industry data and calculate national industry growth rates dropping each city at a time ****

foreach i in "bath" "birmingham" "blackburn" "bolton" "bradford" "brighton" "bristol" "derby" "gateshead" "halifax" "huddersfield" "hull" "ipswich" "leeds" "leicester" "liverpool" "london" "manchester" "newcastle" "northampton" "norwich" "nottingham" "oldham" "portsmouth" "preston" "sheffield" "south_shields" "southampton" "stockport" "sunderland" "wolverhampton" {

use "$root\input_data\CCG_data_agg_analysis_industries", clear
gen new_loc="`i'"
drop if loc=="`i'"
collapse (sum) pop, by(group_2 year new_loc)


gen pop_lag20=0
sort new_loc group_2 year
replace pop_lag20=pop[_n-2] if new_loc==new_loc[_n-2] & group_2==group_2[_n-2]

gen growth20=pop/pop_lag20

keep group_2 year growth20 new_loc
sort group_2 year
save "$root\temp\national_ind_growth_lag20_`i'", replace

}

*** 


** Append
use "$root\temp\national_ind_growth_lag20_birmingham", clear

foreach i in "bath" "blackburn" "bolton" "bradford" "brighton" "bristol" "derby" "gateshead" "halifax" "huddersfield" "hull" "ipswich" "leeds" "leicester" "liverpool" "london" "manchester" "newcastle" "northampton" "norwich" "nottingham" "oldham" "portsmouth" "preston" "sheffield" "south_shields" "southampton" "stockport" "sunderland" "wolverhampton"  {

append using "$root\temp\national_ind_growth_lag20_`i'"

}

rename new_loc loc
sort loc group_2 year
save "$root\temp\national_ind_growth_lag20", replace


** Merge growth rates into main data
use "$root\input_data\CCG_data_agg_analysis_industries", clear


sort loc group_2 year
merge loc group_2 year using "$root\temp\national_ind_growth_lag20"
tab _merge
drop _merge


** Generated predicted employment in each city-industry
gen pop_lag20=0
sort loc group_2 year
replace pop_lag20=pop[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]
gen predicted_pop=pop_lag20*growth20


*** Merge in coal use data
sort group_2
merge group_2 using "$root\input_data\industry_coal_use"
tab _merge
drop _merge
replace cc_per_worker=0 if cc_per_worker==.
replace cc_per_worker=0 if group_2_name=="water_gas_service"

** Coal use variables
replace cc_per_worker=0 if cc_per_worker==.
gen coal_use=pop*cc_per_worker
gen coal_use_iv=predicted_pop*cc_per_worker


** Adjust coal use levels
sort year
merge year using "$root\input_data\coal_use_adjustment_factors"
tab _merge
drop _merge

replace coal_use=coal_use*adjustment_factor
replace coal_use_iv=coal_use_iv*adjustment_factor


*************************************************************************************
***** Merge in connections matrices controls

sort loc group_2 year
merge loc group_2 year using "$root\input_data\prepared_connections_matrices_controls_lag20_IO"
tab _merge
keep if _merge==3
drop _merge

sort loc group_2 year
merge loc group_2 year using "$root\input_data\prepared_connections_matrices_controls_lag20_OCC"
tab _merge
keep if _merge==3
drop _merge


************ Prepare regression variables **********

*** LHS
gen logworkpop=ln(pop)
sort loc group_2 year
gen chg_lnworkpop=logworkpop-logworkpop[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]


*** RHS
gen log_predworkpop=ln(predicted_pop)
sort loc group_2 year
gen chg_ln_pred_workpop=log_predworkpop-logworkpop[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]


* City-level variables
***************** Growth in all other industries except i in city c ****************
** Sum coal use, population in all industries in a city-year
bysort loc year: egen city_coal=sum(coal_use)
bysort loc year: egen city_pop=sum(pop)
bysort loc year: egen city_coal_iv=sum(coal_use_iv)
bysort loc year: egen city_pop_iv=sum(predicted_pop)

** Subtract out own-industry effects
replace city_coal=city_coal-coal_use
replace city_pop=city_pop-pop
replace city_coal_iv=city_coal_iv-coal_use_iv
replace city_pop_iv=city_pop_iv-predicted_pop

** Put city variables in logs
gen ln_city_coal=ln(city_coal)
gen ln_city_pop = ln(city_pop)
gen ln_city_coal_iv=ln(city_coal_iv)
gen ln_city_pop_iv = ln(city_pop_iv)


** Generate changes
sort loc group_2 year
gen chg_ln_city_coal=ln_city_coal-ln_city_coal[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]
sort loc group_2 year
gen chg_ln_city_pop=ln_city_pop-ln_city_pop[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]
sort loc group_2 year
gen chg_ln_city_coal_iv=ln_city_coal_iv-ln_city_coal[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]
sort loc group_2 year
gen chg_ln_city_pop_iv=ln_city_pop_iv-ln_city_pop[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]


** Change in connections matrices controls
gen ln_local_emp_IOout=ln(local_emp_IOout)
gen ln_local_emp_IOin=ln(local_emp_IOin)
gen ln_local_emp_DEM=ln(local_emp_DEM)
gen ln_local_emp_OCC=ln(local_emp_OCC)

replace ln_local_emp_IOout=0 if ln_local_emp_IOout==.
replace ln_local_emp_IOin=0 if ln_local_emp_IOin==.
replace ln_local_emp_DEM=0 if ln_local_emp_DEM==.
replace ln_local_emp_OCC=0 if ln_local_emp_OCC==.

** Change in predicted connections matrices controls
gen ln_pred_IOout=ln(pred_IOout)
gen ln_pred_IOin=ln(pred_IOin)
gen ln_pred_DEM=ln(pred_DEM)
gen ln_pred_OCC=ln(pred_OCC)

replace ln_pred_IOout=0 if ln_pred_IOout==.
replace ln_pred_IOin=0 if ln_pred_IOin==.
replace ln_pred_DEM=0 if ln_pred_DEM==.
replace ln_pred_OCC=0 if ln_pred_OCC==.

sort loc group_2 year
gen chg_ln_IOout=ln_pred_IOout-ln_local_emp_IOout[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]
gen chg_ln_IOin=ln_pred_IOin-ln_local_emp_IOin[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]
gen chg_ln_DEM=ln_pred_DEM-ln_local_emp_DEM[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]
gen chg_ln_OCC=ln_pred_OCC-ln_local_emp_OCC[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]

sort loc group_2 year
gen lag_ln_IOin=ln_IOin[_n-1] if loc==loc[_n-1] & group_2==group_2[_n-1]
gen lag_ln_IOout=ln_IOout[_n-1] if loc==loc[_n-1] & group_2==group_2[_n-1]
gen lag_ln_DEM=ln_DEM[_n-1] if loc==loc[_n-1] & group_2==group_2[_n-1]
gen lag_ln_OCC=ln_OCC[_n-1] if loc==loc[_n-1] & group_2==group_2[_n-1]

***** Merge in city controls
sort loc
merge loc using "$root\input_data\city_characteristics"
tab _merge
keep if _merge==3
drop _merge


** Encode
encode loc, gen(loc_code)
tostring group_2, gen(group_2_str)
gen loc_ind=loc+group_2_str
encode loc_ind, gen(loc_ind_code)
tostring year, gen(year_str)
gen loc_yr=loc+year_str
encode loc_yr, gen(loc_yr_code)

gen yr_code=1
replace yr_code=2 if year==1881
replace yr_code=3 if year==1891
replace yr_code=4 if year==1901
replace yr_code=5 if year==1911
drop if year<1871

** Prepare for regressions
xtset loc_ind_code yr_code
xi i.year*i.group_2 i.loc*i.year, noomit
gen ones=1
drop  _Iyear_1871 _IyeaXgro_1871_310


** Label variables
label variable chg_lnworkpop "$\Delta Ln(Emp)$"
label variable chg_ln_pred_workpop "$\Delta Ln(L_{i-ct})$"
label variable chg_ln_city_pop_iv "$\Delta Ln(PredCityPop)$"
label variable chg_ln_city_coal_iv "$\Delta Ln(PredCoal)$"
label variable chg_ln_IOin "$\Delta Ln(IOin)$"
label variable chg_ln_IOout "$\Delta Ln(IOout)$"
label variable chg_ln_DEM "$\Delta Ln(DEM)$"
label variable chg_ln_OCC "$\Delta Ln(OCC)$"
label variable ones "Constant"
drop if chg_lnworkpop==.


**** Table 2 Column 16
ols_spatial_HAC chg_lnworkpop  chg_ln_city_pop_iv chg_ln_city_coal_iv chg_ln_IOin _IyeaX* ones, lat(lat) lon(lon) timevar(yr_code) panelvar(loc_ind_code) distcutoff(1) lagcutoff(2) star

**** Table 2 Column 17
ols_spatial_HAC chg_lnworkpop   chg_ln_city_pop_iv chg_ln_city_coal_iv chg_ln_IOout _IyeaX* ones, lat(lat) lon(lon) timevar(yr_code) panelvar(loc_ind_code) distcutoff(1) lagcutoff(2) star

**** Table 2 Column 18
ols_spatial_HAC chg_lnworkpop  chg_ln_city_pop_iv chg_ln_city_coal_iv chg_ln_DEM _IyeaX* ones, lat(lat) lon(lon) timevar(yr_code) panelvar(loc_ind_code) distcutoff(1) lagcutoff(2) star

**** Table 2 Column 19
ols_spatial_HAC chg_lnworkpop  chg_ln_city_pop_iv chg_ln_city_coal_iv chg_ln_OCC _IyeaX* ones, lat(lat) lon(lon) timevar(yr_code) panelvar(loc_ind_code) distcutoff(1) lagcutoff(2) star

**** Table 2 Column 20
ols_spatial_HAC chg_lnworkpop  chg_ln_city_pop_iv chg_ln_city_coal_iv chg_ln_IOout chg_ln_IOin chg_ln_DEM chg_ln_OCC _IyeaX* ones, lat(lat) lon(lon) timevar(yr_code) panelvar(loc_ind_code) distcutoff(1) lagcutoff(2) star

