clear
capture log close
set more off 
set mem 500m


*** Set global here
global root "C:\Users\Walker\Dropbox\Coal_and_city_growth\EJ_replication_files"
global temp "$root\temp"


***** Begin with city-industry data and calculate national industry growth rates dropping each city at a time ****

foreach i in "bath" "birmingham" "blackburn" "bolton" "bradford" "brighton" "bristol" "derby" "gateshead" "halifax" "huddersfield" "hull" "ipswich" "leeds" "leicester" "liverpool" "london" "manchester" "newcastle" "northampton" "norwich" "nottingham" "oldham" "portsmouth" "preston" "sheffield" "south_shields" "southampton" "stockport" "sunderland" "wolverhampton" {

use "$root\input_data\CCG_data_agg_analysis_industries", clear
gen new_loc="`i'"
drop if loc=="`i'"
collapse (sum) pop, by(group_2 year new_loc)


gen pop_lag20=0
sort new_loc group_2 year
replace pop_lag20=pop[_n-2] if new_loc==new_loc[_n-2] & group_2==group_2[_n-2]

gen growth20=pop/pop_lag20

keep group_2 year growth20 new_loc
sort group_2 year
save "$root\temp\national_ind_growth_lag20_`i'", replace

}

*** 


** Append
use "$root\temp\national_ind_growth_lag20_birmingham", clear

foreach i in "bath" "blackburn" "bolton" "bradford" "brighton" "bristol" "derby" "gateshead" "halifax" "huddersfield" "hull" "ipswich" "leeds" "leicester" "liverpool" "london" "manchester" "newcastle" "northampton" "norwich" "nottingham" "oldham" "portsmouth" "preston" "sheffield" "south_shields" "southampton" "stockport" "sunderland" "wolverhampton"  {

append using "$root\temp\national_ind_growth_lag20_`i'"

}

rename new_loc loc
sort loc group_2 year
save "$root\temp\national_ind_growth_lag20", replace


** Merge growth rates into main data
use "$root\input_data\CCG_data_agg_analysis_industries", clear

sort loc group_2 year
merge loc group_2 year using "$root\temp\national_ind_growth_lag20"
tab _merge
drop _merge


** Generated predicted employment in each city-industry
gen pop_lag20=0
sort loc group_2 year
replace pop_lag20=pop[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]
gen predicted_pop=pop_lag20*growth20



** Merge in salary share data
sort group_2
merge group_2 using "$root\input_data\industry_salaried_shares"
tab _merge


** Drop non-manufacturing industries and unnecessary variables
keep if _merge==3
drop if group_2_name=="builder"
drop if group_2_name=="water_gas_service"
drop if group_2_name=="mining_related"
drop wage_workers salary_workers
drop _merge

**** Merge in industry input shares
sort group_2
merge group_2 using "$root\input_data\input_shares_for_estimation"
tab _merge
keep if _merge==3
drop _merge

**** Merge in industry input demands
sort group_2
merge group_2 using "$root\input_data\industry_demands"
tab _merge
keep if _merge==3
drop _merge


*** Merge in coal use data
sort group_2
merge group_2 using "$root\input_data\industry_coal_use"
tab _merge
drop _merge


** Coal use variables
replace cc_per_worker=0 if cc_per_worker==.
gen coal_use=pop*cc_per_worker
gen coal_use_iv=predicted_pop*cc_per_worker


** Adjust coal use levels
sort year
merge year using "$root\input_data\coal_use_adjustment_factors"
tab _merge
drop _merge

replace coal_use=coal_use*adjustment_factor
replace coal_use_iv=coal_use_iv*adjustment_factor


** City coal use values
bysort loc year: egen city_coal=sum(coal_use)
bysort loc year: egen city_coal_iv=sum(coal_use_iv)


**** Merge in industry firm size data
sort group_2
merge group_2 using "$root\input_data\prepared_national_firm_size_data"
tab _merge
keep if _merge==3
drop _merge

replace cc_per_worker=0 if cc_per_worker==.


**** Merge in industry demographics controls
sort group_2
merge group_2 using "$root\input_data\prepared_industry_demographics"
tab _merge
keep if _merge==3
drop _merge


** Salaried workers share variables
gen salaried_emp=pop*salary_shr
gen salaried_iv=predicted_pop*salary_shr

** Firm size variable
gen firm_size=med_worker_firm*pop
gen firm_size_iv=med_worker_firm*predicted_pop

** Labor cost share variable
gen ind_labor_shr=pop*(1-labor_shr)
gen ind_labor_shr_iv=predicted_pop*(1-labor_shr)


** Exports share variable
gen ind_exp_shr=pop*exports_shr
gen ind_exp_shr_iv=predicted_pop*exports_shr

** Female and youth share variables
gen ind_fem_shr=pop*female_shr
gen ind_fem_shr_iv=predicted_pop*female_shr
gen ind_youth_shr=pop*youth_shr
gen ind_youth_shr_iv=predicted_pop*youth_shr


************ Prepare regression variables **********

*** LHS
gen logworkpop=ln(pop)
sort loc group_2 year
gen chg_lnworkpop=logworkpop-logworkpop[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]


*** RHS
gen log_predworkpop=ln(predicted_pop)
sort loc group_2 year
gen chg_ln_pred_workpop=log_predworkpop-logworkpop[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]


* City-level variables
***************** Growth in all other industries except i in city c ****************
** Sum coal use, population in all industries in a city-year
bysort loc year: egen city_pop=sum(pop)
bysort loc year: egen city_pop_iv=sum(predicted_pop)


** Subtract out own-industry effects
replace city_coal=city_coal-coal_use
replace city_pop=city_pop-pop
replace city_coal_iv=city_coal_iv-coal_use_iv
replace city_pop_iv=city_pop_iv-predicted_pop

** Put city variables in logs
gen ln_city_coal=ln(city_coal)
gen ln_city_pop = ln(city_pop)
gen ln_city_coal_iv=ln(city_coal_iv)
gen ln_city_pop_iv = ln(city_pop_iv)


** Generate changes
sort loc group_2 year
gen chg_ln_city_coal=ln_city_coal-ln_city_coal[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]
sort loc group_2 year
gen chg_ln_city_pop=ln_city_pop-ln_city_pop[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]
sort loc group_2 year
gen chg_ln_city_coal_iv=ln_city_coal_iv-ln_city_coal[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]
sort loc group_2 year
gen chg_ln_city_pop_iv=ln_city_pop_iv-ln_city_pop[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]


*** Control variables
bysort loc year: egen city_salaried=sum(salaried_emp)
bysort loc year: egen city_salaried_iv=sum(salaried_iv)

bysort loc year: egen city_firm_size=sum(firm_size)
bysort loc year: egen city_firm_size_iv=sum(firm_size_iv)

bysort loc year: egen city_labor=sum(ind_labor_shr)
bysort loc year: egen city_labor_iv=sum(ind_labor_shr_iv)

bysort loc year: egen city_exp=sum(ind_exp_shr)
bysort loc year: egen city_exp_iv=sum(ind_exp_shr_iv)

bysort loc year: egen city_fem=sum(ind_fem_shr)
bysort loc year: egen city_fem_iv=sum(ind_fem_shr_iv)

bysort loc year: egen city_youth=sum(ind_youth_shr)
bysort loc year: egen city_youth_iv=sum(ind_youth_shr_iv)


** Dropping own-industry effects
replace city_salaried=city_salaried-salaried_emp
replace city_salaried_iv=city_salaried_iv-salaried_iv

replace city_firm_size=city_firm_size-firm_size
replace city_firm_size_iv=city_firm_size_iv-firm_size_iv

replace city_labor=city_labor-ind_labor_shr
replace city_labor_iv=city_labor_iv-ind_labor_shr_iv

replace city_exp=city_exp-ind_exp_shr
replace city_exp_iv=city_exp_iv-ind_exp_shr_iv

replace city_fem=city_fem-ind_fem_shr
replace city_fem_iv=city_fem_iv-ind_fem_shr_iv

replace city_youth=city_youth-ind_youth_shr
replace city_youth_iv=city_youth_iv-ind_youth_shr_iv


** Employment-weighted industry averages
gen city_salary_shr=city_salaried/city_pop
gen city_salary_shr_iv=city_salaried_iv/city_pop_iv

gen city_firm_size_avg=city_firm_size/city_pop
gen city_firm_size_avg_iv=city_firm_size_iv/city_pop_iv

gen city_labor_shr=city_labor/city_pop
gen city_labor_shr_iv=city_labor_iv/city_pop_iv

gen city_exp_shr=city_exp/city_pop
gen city_exp_shr_iv=city_exp_iv/city_pop_iv

gen city_fem_shr=city_fem/city_pop
gen city_fem_shr_iv=city_fem_iv/city_pop_iv

gen city_youth_shr=city_youth/city_pop
gen city_youth_shr_iv=city_youth_iv/city_pop_iv


** Put in logs
gen ln_city_salary_shr=ln(city_salary_shr)
gen ln_city_salary_shr_iv=ln(city_salary_shr_iv)
gen ln_city_firm_size_avg=ln(city_firm_size_avg)
gen ln_city_firm_size_avg_iv=ln(city_firm_size_avg_iv)
gen ln_city_labor_shr=ln(city_labor_shr)
gen ln_city_labor_shr_iv=ln(city_labor_shr_iv)
gen ln_city_exp_shr=ln(city_exp_shr)
gen ln_city_exp_shr_iv=ln(city_exp_shr_iv)

gen ln_city_fem_shr=ln(city_fem_shr)
gen ln_city_fem_shr_iv=ln(city_fem_shr_iv)

gen ln_city_youth_shr=ln(city_youth_shr)
gen ln_city_youth_shr_iv=ln(city_youth_shr_iv)


** Now in changes
sort loc group_2 year
gen chg_ln_salary_shr=ln_city_salary_shr-ln_city_salary_shr[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]
gen chg_ln_salary_shr_iv=ln_city_salary_shr_iv-ln_city_salary_shr[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]

gen chg_ln_firm_size=ln_city_firm_size_avg-ln_city_firm_size_avg[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]
gen chg_ln_firm_size_iv=ln_city_firm_size_avg_iv-ln_city_firm_size_avg[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]

gen chg_ln_labor_shr=ln_city_labor_shr-ln_city_labor_shr[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]
gen chg_ln_labor_shr_iv=ln_city_labor_shr_iv-ln_city_labor_shr[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]

gen chg_ln_exp_shr=ln_city_exp_shr-ln_city_exp_shr[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]
gen chg_ln_exp_shr_iv=ln_city_exp_shr_iv-ln_city_exp_shr[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]

gen chg_ln_fem_shr=ln_city_fem_shr-ln_city_fem_shr[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]
gen chg_ln_fem_shr_iv=ln_city_fem_shr_iv-ln_city_fem_shr[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]

gen chg_ln_youth_shr=ln_city_youth_shr-ln_city_youth_shr[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]
gen chg_ln_youth_shr_iv=ln_city_youth_shr_iv-ln_city_youth_shr[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]


***** Merge in city controls
sort loc
merge loc using "$root\input_data\city_characteristics"
tab _merge
keep if _merge==3
drop _merge


** Encode variables
encode loc, gen(loc_code)
tostring group_2, gen(group_2_str)
gen loc_ind=loc+group_2_str
encode loc_ind, gen(loc_ind_code)
tostring year, gen(year_str)
gen loc_yr=loc+year_str
encode loc_yr, gen(loc_yr_code)

gen yr_code=1
replace yr_code=2 if year==1881
replace yr_code=3 if year==1891
replace yr_code=4 if year==1901
replace yr_code=5 if year==1911
drop if year<1871


** Prepare for regressions
xtset loc_ind_code yr_code
xi i.year*i.group_2, noomit
gen ones=1
drop  _Iyear_1871 _IyeaXgro_1871_310


** Label variables
label variable chg_lnworkpop "$\Delta Ln(Emp)$"
label variable chg_ln_pred_workpop "$\Delta Ln(L_{i-ct})$"
label variable chg_ln_city_pop_iv "$\Delta Ln(PredCityPop)$"
label variable chg_ln_city_coal_iv "$\Delta Ln(PredCoal)$"
label variable chg_ln_salary_shr_iv "$\Delta Ln(Salaried wkr. shr.)$"
label variable chg_ln_firm_size_iv "$\Delta Ln(Avg. firm size)$"
label variable chg_ln_labor_shr_iv "$\Delta Ln(Labor cost shr.)$"
label variable chg_ln_exp_shr_iv "$\Delta Ln(Exports shr.)$"
label variable chg_ln_fem_shr_iv "$\Delta Ln(Female emp. shr.)$"
label variable chg_ln_youth_shr_iv "$\Delta Ln(Youth emp. shr.)$"
drop if chg_lnworkpop==.

bob;
**** Table 2 Column 9
ols_spatial_HAC chg_lnworkpop chg_ln_city_pop_iv chg_ln_city_coal_iv chg_ln_salary_shr_iv _IyeaX* ones, lat(lat) lon(lon) timevar(yr_code) panelvar(loc_ind_code) distcutoff(1) lagcutoff(2) star

**** Table 2 Column 10
ols_spatial_HAC chg_lnworkpop chg_ln_city_pop_iv chg_ln_city_coal_iv chg_ln_firm_size_iv _IyeaX* ones, lat(lat) lon(lon) timevar(yr_code) panelvar(loc_ind_code) distcutoff(1) lagcutoff(2) star

**** Table 2 Column 11
ols_spatial_HAC chg_lnworkpop chg_ln_city_pop_iv chg_ln_city_coal_iv chg_ln_exp_shr_iv _IyeaX* ones, lat(lat) lon(lon) timevar(yr_code) panelvar(loc_ind_code) distcutoff(1) lagcutoff(2) star

**** Table 2 Column 12
ols_spatial_HAC chg_lnworkpop chg_ln_city_pop_iv chg_ln_city_coal_iv chg_ln_labor_shr_iv _IyeaX* ones, lat(lat) lon(lon) timevar(yr_code) panelvar(loc_ind_code) distcutoff(1) lagcutoff(2) star

**** Table 2 Column 13
ols_spatial_HAC chg_lnworkpop chg_ln_city_pop_iv chg_ln_city_coal_iv chg_ln_fem_shr_iv _IyeaX* ones, lat(lat) lon(lon) timevar(yr_code) panelvar(loc_ind_code) distcutoff(1) lagcutoff(2) star

**** Table 2 Column 14
ols_spatial_HAC chg_lnworkpop chg_ln_city_pop_iv chg_ln_city_coal_iv chg_ln_youth_shr_iv _IyeaX* ones, lat(lat) lon(lon) timevar(yr_code) panelvar(loc_ind_code) distcutoff(1) lagcutoff(2) star

**** Table 2 Column 15
ols_spatial_HAC chg_lnworkpop chg_ln_city_pop_iv chg_ln_city_coal_iv chg_ln_salary_shr_iv chg_ln_firm_size_iv chg_ln_exp_shr_iv chg_ln_labor_shr_iv chg_ln_fem_shr_iv chg_ln_youth_shr_iv _IyeaX* ones, lat(lat) lon(lon) timevar(yr_code) panelvar(loc_ind_code) distcutoff(1) lagcutoff(2) star



