clear
capture log close
set more off 
set mem 500m


*** Set global here
global root "C:\Users\Walker\Dropbox\Coal_and_city_growth\EJ_replication_files"
global temp "$root\temp"


***** Begin with city-industry data and calculate national industry growth rates dropping one city at a time ****

foreach i in "bath" "birmingham" "blackburn" "bolton" "bradford" "brighton" "bristol" "derby" "gateshead" "halifax" "huddersfield" "hull" "ipswich" "leeds" "leicester" "liverpool" "london" "manchester" "newcastle" "northampton" "norwich" "nottingham" "oldham" "portsmouth" "preston" "sheffield" "south_shields" "southampton" "stockport" "sunderland" "wolverhampton" {

use "$root\input_data\CCG_data_agg_analysis_industries", clear
gen new_loc="`i'"
drop if loc=="`i'"
collapse (sum) pop, by(group_2 year new_loc)


gen pop_lag20=0
sort new_loc group_2 year
replace pop_lag20=pop[_n-2] if new_loc==new_loc[_n-2] & group_2==group_2[_n-2]

gen growth20=pop/pop_lag20

keep group_2 year growth20 new_loc
sort group_2 year
save "$root\temp\national_ind_growth_lag20_`i'_all_ind", replace

}

** Append
use "$root\temp\national_ind_growth_lag20_birmingham_all_ind", clear

foreach i in "bath" "blackburn" "bolton" "bradford" "brighton" "bristol" "derby" "gateshead" "halifax" "huddersfield" "hull" "ipswich" "leeds" "leicester" "liverpool" "london" "manchester" "newcastle" "northampton" "norwich" "nottingham" "oldham" "portsmouth" "preston" "sheffield" "south_shields" "southampton" "stockport" "sunderland" "wolverhampton" {

append using "$root\temp\national_ind_growth_lag20_`i'_all_ind"

}


rename new_loc loc
sort loc group_2 year
save "$root\temp\national_ind_growth_lag20_all_ind", replace




********************** Merge growth rates into main data ***********************
use "$root\input_data\CCG_data_agg_analysis_industries", clear


sort loc group_2 year
merge loc group_2 year using "$root\temp\national_ind_growth_lag20_all_ind"
tab _merge
drop _merge


** Generated predicted employment in each city-industry
gen pop_lag20=0
sort loc group_2 year
replace pop_lag20=pop[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]
gen predicted_pop=pop_lag20*growth20


*** Merge in coal use data
sort group_2
merge group_2 using "$root\input_data\industry_coal_use"
tab _merge
drop _merge
replace cc_per_worker=0 if cc_per_worker==.
replace cc_per_worker=0 if group_2_name=="builder"


** Coal use variables
replace cc_per_worker=0 if cc_per_worker==.
gen coal_use=pop*cc_per_worker
gen coal_use_iv=predicted_pop*cc_per_worker


** Adjust coal use levels
sort year
merge year using "$root\input_data\coal_use_adjustment_factors"
tab _merge
drop _merge

replace coal_use=coal_use*adjustment_factor
replace coal_use_iv=coal_use_iv*adjustment_factor


***************************************************
** Collapse to city-year level
collapse (sum) pop predicted_pop coal_use coal_use_iv, by(loc year)


**** Merge in city population data
sort loc year
merge loc year using "$root\input_data\city_pop"
tab _merge
drop _merge


************ Prepare regression variables **********

*** LHS
gen logtotpop=ln(pop_total)
sort loc year
gen chg_log_totpop=logtotpop-logtotpop[_n-2] if loc==loc[_n-2]


*** RHS
gen log_pop=ln(pop)
gen log_predpop=ln(predicted_pop)
sort loc year
gen chg_log_predpop=log_predpop-log_pop[_n-2] if loc==loc[_n-2]


*** Change in log coal iv compared to two decades before
gen ln_coal=ln(coal_use)
gen ln_coal_iv=ln(coal_use_iv)

sort loc year
gen chg_ln_coal_use=ln_coal-ln_coal[_n-2] if loc==loc[_n-2]
sort loc year
gen chg_ln_coal_use_iv=ln_coal_iv-ln_coal[_n-2] if loc==loc[_n-2]


***** Merge in city controls
sort loc
merge loc using "$root\input_data\city_characteristics"
tab _merge
drop _merge

** Encode year
gen yr_code=0
replace yr_code=1 if year==1861
replace yr_code=2 if year==1871
replace yr_code=3 if year==1881
replace yr_code=4 if year==1891
replace yr_code=5 if year==1901
replace yr_code=6 if year==1911

** Prepare for regressions
encode loc, gen(loc_code)
xtset loc_code yr_code
xi i.year
gen ones=1

** Label variables
label variable chg_log_predpop "$\Delta \ln(PrWorkpop_{ct})$"
label variable chg_ln_coal_use_iv "$\Delta \ln(PrCoal_{ct})$"


*** Run regression and extract coefficients
reg chg_log_totpop chg_log_predpop chg_ln_coal_use_iv _Iyear* if year>1861, robust
local CC=_b[chg_ln_coal_use_iv]
local PC=_b[chg_log_predpop]


****** Use coefficients to calculate counterfactual growth
keep loc year pop_total coal_use
gen ln_pop=ln(pop_total)
sort loc year
gen gr_pop=ln_pop-ln_pop[_n-1] if loc==loc[_n-1]

gen ln_coal=ln(coal_use)
gen chg_ln_coal=ln_coal-ln_coal[_n-1] if loc==loc[_n-1]

*** Counterfactual growth rates
gen counterfactual_gr=.
gen counterfactual_gr_adj=.
replace counterfactual_gr=gr_pop-(`CC')*(0.1)*chg_ln_coal
replace counterfactual_gr_adj=gr_pop-(`CC')*(0.1)*chg_ln_coal

*** New population
gen ln_newpop=.
replace ln_newpop=ln_pop[_n-1]+counterfactual_gr if year==1861 & loc==loc[_n-1]
replace ln_newpop=ln_newpop[_n-1] +counterfactual_gr if year>1861 & loc==loc[_n-1]
gen newpop=exp(ln_newpop)
replace newpop=pop_total if year==1851

*** collapse to national levels
preserve
collapse (sum) pop_total newpop, by(year)
save "$root\Table_4\results\total_urbanization", replace
outsheet using "$root\Table_4\results\total_urbanization.csv", comma names replace
restore



