clear
capture log close
set more off 
set mem 500m


*** Set global here
global root "C:\Users\Walker\Dropbox\Coal_and_city_growth\EJ_replication_files"
global temp "$root\temp"



*************************** Prepare data *********************************
use "$root\input_data\QOL_analysis_data", clear

*** Merge in coal use data
sort group_2
merge group_2 using "$root\input_data\industry_coal_use"
tab _merge
keep if _merge==3
drop _merge


** Coal use varaibles
gen coal_use=pop*cc_per_worker

** Collapse to city-year level
collapse (sum) pop coal_use, by(loc year)


** Merge in Board of Trade data
sort loc
merge loc using "$root\input_data\bot_data_all"
tab _merge
keep if _merge==3
drop _merge


***** Merge in city characteristics
sort loc
merge loc using "$root\input_data\city_characteristics_qol_analysis"
tab _merge
keep if _merge==3
drop _merge

** Generate variables
gen log_coal_use=ln(coal_use)
gen log_town_pop=ln(town_pop)

**** Generate quality of life variables
replace combined=ln(combined)
replace wages_skilled_builders=ln(wages_skilled_builders)
replace wages_skilled_engineering=ln(wages_skilled_engineering)

*** Quality of life variables
gen QOL_skb=combined-wages_skilled_builders
gen QOL_ske=combined-wages_skilled_engineering

** Prepare variables
label variable log_coal_use "$Ln(COAL_c)$"
label variable log_town_pop "$Ln(POP_c)$"
label variable air_frost "Air frost days"
label variable rainfall "Rainfall"


*** Prepare for analysis
gen ones=1
encode loc, gen(loc_code)
xtset loc_code year
xi i.region


**** Table 5 Column 1
reg QOL_skb log_coal_use, robust

**** Table 5 Column 2
reg QOL_skb log_coal_use log_town_pop, robust

**** Table 5 Column 3
reg QOL_skb log_coal_use  log_town_pop air_frost rainfall, robust

**** Table 5 Column 4
reg QOL_ske log_coal_use, robust

**** Table 5 Column 5
reg QOL_ske log_coal_use log_town_pop, robust

**** Table 5 Column 6
reg QOL_ske log_coal_use log_town_pop air_frost rainfall, robust



