clear
capture log close
set more off


*** Laptop global
global root "C:\Users\Walker\Dropbox\Coal_and_city_growth\EJ_replication_files"
global input "$root\prepare_control_variables\connections_matrices_controls\data"

global temp "$root\temp"

*** 1. Load and prepare connections matrices *****

*********** Important notes ****************
*** perc_in is the percent of inputs to col_ind from each other sector
*** prec_out is the percent of output from the row industry sold to each other sector

*** IO out
use "$input\IO_table_long", clear
* keep the industry identifiers and the IOout measure
keep row_ind col_ind perc_out
* Drop agriculture
drop if row_ind==0
drop if col_ind==0
* Set the row industry as the base industry -- this is the sellind industry
rename row_ind group_2_1
rename col_ind group_2_2
rename perc_out IOout
sort group_2_1 group_2_2
save "$temp\IOout", replace


*** IO in
use "$input\IO_table_long", clear
* keep the industry identifiers and the IOin measure
keep row_ind col_ind perc_in
* drop agriculture
drop if row_ind==0
drop if col_ind==0
* make the column industry the base industry -- this is the buying industry
rename col_ind group_2_1
rename row_ind group_2_2
rename perc_in IOin
sort group_2_1 group_2_2
save "$temp\IOin", replace



*** Merge matrices -- IO
use "$temp\IOout", replace

sort group_2_1 group_2_2
merge group_2_1 group_2_2 using "$temp\IOin"
tab _merge
drop _merge


*** Limit to available industries
drop if group_2_1==300
drop if group_2_2==300
drop if group_2_1==709
drop if group_2_2==709
drop if group_2_1==1110
drop if group_2_2==1110
drop if group_2_1==1410
drop if group_2_2==1410
drop if group_2_1==1907
drop if group_2_2==1907


** Drop own-industry observations
drop if group_2_1==group_2_2

** Replace missing with zeros
replace IOout=0 if IOout==.
replace IOin=0 if IOin==.

sort group_2_1
save "$temp\connections_matrices_IO", replace

*** Prepare connections matrices crosswalk
use "$input\ind_crosswalk", clear
sort group_2
save "$input\ind_crosswalk", replace



*******************************************

****** 2. Prepare predicted city-industry growth data
foreach i in "bath" "birmingham" "blackburn" "bolton" "bradford" "brighton" "bristol" "derby" "gateshead" "halifax" "huddersfield" "hull" "ipswich" "leeds" "leicester" "liverpool" "london" "manchester" "newcastle" "northampton" "norwich" "nottingham" "oldham" "portsmouth" "preston" "sheffield" "south_shields" "southampton" "stockport" "sunderland" "wolverhampton" {
use "$root\input_data\CCG_data_agg_analysis_industries", clear
gen new_loc="`i'"
drop if loc=="`i'"

** Adjust to IO industry categories
sort group_2
merge group_2 using "$input\ind_crosswalk"
tab _merge
collapse (sum) pop, by(group_2_IO year new_loc)
rename group_2_IO group_2

gen pop_lag20=0
sort new_loc group_2 year
replace pop_lag20=pop[_n-2] if new_loc==new_loc[_n-2] & group_2==group_2[_n-2]

gen growth20=pop/pop_lag20

keep group_2 year growth20 new_loc
sort group_2 year
save "$temp\national_ind_growth_lag20_`i'", replace

}

** Append
use "$temp\national_ind_growth_lag20_birmingham", clear

foreach i in "bath" "blackburn" "bolton" "bradford" "brighton" "bristol" "derby" "gateshead" "halifax" "huddersfield" "hull" "ipswich" "leeds" "leicester" "liverpool" "london" "manchester" "newcastle" "northampton" "norwich" "nottingham" "oldham" "portsmouth" "preston" "sheffield" "south_shields" "southampton" "stockport" "sunderland" "wolverhampton"  {
append using "$temp\national_ind_growth_lag20_`i'"

}

rename new_loc loc
sort loc group_2 year
save "$temp\national_ind_growth_lag20", replace

*****************


** Merge growth rates into main data
use "$root\input_data\CCG_data_agg_analysis_industries", clear

** Adjust to IO industry categories
sort group_2
merge group_2 using "$input\ind_crosswalk"
tab _merge
collapse (sum) pop, by(group_2_IO year loc)
rename group_2_IO group_2

sort loc group_2 year
merge loc group_2 year using "$temp\national_ind_growth_lag20"
tab _merge
drop _merge

** Generated predicted employment in each city-industry
gen pop_lag20=0
sort loc group_2 year
replace pop_lag20=pop[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]
gen predicted_pop=pop_lag20*growth20

*** Limit to available industries
drop if group_2==300
drop if group_2==709
drop if group_2==1110
drop if group_2==1410
drop if group_2==1907

* Save
sort group_2
save "$temp\city_industry_data_connections_matrices_IO_lag20", replace


*******************************************



******* 3. For each industry, merge in connections matrices and sum

**** First for IO

foreach i in 310 601 700 800 1117 1119 1120 1201 1206 1210 1404 1509 1607 1701 1801 1906 2027 {

*local i=706
* load connections matrices values --IO
use "$temp\connections_matrices_IO", clear
* limit to the base industry -- so our values focus only in industry i
keep if group_2_1==`i'
drop group_2_1
rename group_2_2 group_2
* group_2 not contains an indentifier for all industries other than i
sort group_2
save "$temp\connections_matrices_IO_`i'", replace



* load employment data
use "$temp\city_industry_data_connections_matrices_IO_lag20", replace


* merge in IO connections matrices for industry `i' to all other industries
* Need to use group_2_new for IO merger
sort group_2
merge group_2 using "$temp\connections_matrices_IO_`i'"
tab _merge
keep if _merge==3
drop _merge


* in logs -- This is the approach used in Hanlon + Miscio
gen ln_pop=ln(pop)
replace ln_pop=0 if ln_pop==.
gen ln_IOout=ln_pop*IOout 
gen ln_IOin=ln_pop*IOin


* in employment levels
gen local_emp_IOout=pop*IOout 
gen local_emp_IOin=pop*IOin

* in levels, with predicted employment (don't worry about this)
gen pred_IOout=predicted_pop*IOout 
gen pred_IOin=predicted_pop*IOin

* Collapse by city year
collapse (sum) local_emp* pred* ln_*, by(loc year)

* identify observation industry
gen group_2=`i'

save "$temp\connections_matrices_controls_`i'_IO", replace

}

*** Generate copies of duplicated group codes
** 506
use "$temp\connections_matrices_controls_700_IO", clear
replace group_2=506
save "$temp\connections_matrices_controls_506_IO", replace

** 702
use "$temp\connections_matrices_controls_700_IO", clear
replace group_2=702
save "$temp\connections_matrices_controls_702_IO", replace

** 706
use "$temp\connections_matrices_controls_800_IO", clear
replace group_2=706
save "$temp\connections_matrices_controls_706_IO", replace

** 801
use "$temp\connections_matrices_controls_800_IO", clear
replace group_2=801
save "$temp\connections_matrices_controls_801_IO", replace

** 802
use "$temp\connections_matrices_controls_800_IO", clear
replace group_2=802
save "$temp\connections_matrices_controls_802_IO", replace

** 809
use "$temp\connections_matrices_controls_800_IO", clear
replace group_2=809
save "$temp\connections_matrices_controls_809_IO", replace

** 811
use "$temp\connections_matrices_controls_800_IO", clear
replace group_2=811
save "$temp\connections_matrices_controls_811_IO", replace

** 1121
use "$temp\connections_matrices_controls_1120_IO", clear
replace group_2=1121
save "$temp\connections_matrices_controls_1121_IO", replace

** 1901
use "$temp\connections_matrices_controls_1120_IO", clear
replace group_2=1901
save "$temp\connections_matrices_controls_1901_IO", replace



****** append all of the matrices
use "$temp\connections_matrices_controls_310_IO", clear

foreach i in 506 601 702 706 801 802 809 811  1117 1119 1121 1201 1206 1210 1404  1509 1607 1701 1801 1901 1906  2027 {

append using  "$temp\connections_matrices_controls_`i'_IO"

}

** save
sort loc group_2 year
save "$root\input_data\prepared_connections_matrices_controls_lag20_IO", replace


***
