clear
capture log close
set more off


*** Laptop global
global root "C:\Users\Walker\Dropbox\Coal_and_city_growth\EJ_replication_files"
global input "$root\prepare_control_variables\connections_matrices_controls\data"

global temp "$root\temp"

*** 1. Load and prepare connections matrices *****


*** DEM
use "$input\occ_sim_EMP_matrix", clear
keep group_2_1 group_2_2 yr1851_both
rename yr1851_both DEMsim
destring group_2_1, replace
destring group_2_2, replace
sort group_2_1 group_2_2 
save "$temp\DEM", replace


*** OCC
use "$input\occ_sim_OCC_matrix", clear
rename occ_sim_1880_occ1950 OCCsim
destring group_2_1, replace
destring group_2_2, replace
sort group_2_1 group_2_2 
save "$temp\OCC", replace



*** Merge matrices - DEM and OCC
use "$temp\DEM", replace

sort group_2_1 group_2_2
merge group_2_1 group_2_2 using "$temp\OCC"
tab _merge
drop _merge


*** Limit to available industries
drop if group_2_1==300
drop if group_2_2==300
drop if group_2_1==709
drop if group_2_2==709
drop if group_2_1==1110
drop if group_2_2==1110
drop if group_2_1==1410
drop if group_2_2==1410
drop if group_2_1==1907
drop if group_2_2==1907


** Drop own-industry observations
drop if group_2_1==group_2_2

** Replace missing with zeros
replace DEMsim=0 if DEMsim==.
replace OCCsim=0 if OCCsim==.

save "$temp\connections_matrices_DEM_OCC", replace




*******************************************

****** 2. Prepare predicted city-industry growth data -- not too important
foreach i in "bath" "birmingham" "blackburn" "bolton" "bradford" "brighton" "bristol" "derby" "gateshead" "halifax" "huddersfield" "hull" "ipswich" "leeds" "leicester" "liverpool" "london" "manchester" "newcastle" "northampton" "norwich" "nottingham" "oldham" "portsmouth" "preston" "sheffield" "south_shields" "southampton" "stockport" "sunderland" "wolverhampton" {
use "$root\input_data\CCG_data_agg_analysis_industries", clear
gen new_loc="`i'"
drop if loc=="`i'"
collapse (sum) pop, by(group_2 year new_loc)


gen pop_lag20=0
sort new_loc group_2 year
replace pop_lag20=pop[_n-2] if new_loc==new_loc[_n-2] & group_2==group_2[_n-2]

gen growth20=pop/pop_lag20

keep group_2 year growth20 new_loc
sort group_2 year
save "$root\temp\national_ind_growth_lag20_`i'", replace

}

** Append
use "$root\temp\national_ind_growth_lag20_birmingham", clear

foreach i in "bath" "blackburn" "bolton" "bradford" "brighton" "bristol" "derby" "gateshead" "halifax" "huddersfield" "hull" "ipswich" "leeds" "leicester" "liverpool" "london" "manchester" "newcastle" "northampton" "norwich" "nottingham" "oldham" "portsmouth" "preston" "sheffield" "south_shields" "southampton" "stockport" "sunderland" "wolverhampton"  {
append using "$root\temp\national_ind_growth_lag20_`i'"

}

rename new_loc loc
sort loc group_2 year
save "$root\temp\national_ind_growth_lag20", replace

*****************


** Merge growth rates into main data
use "$root\input_data\CCG_data_agg_analysis_industries", clear

sort loc group_2 year
merge loc group_2 year using "$root\temp\national_ind_growth_lag20"
tab _merge
drop _merge

** Generated predicted employment in each city-industry
gen pop_lag20=0
sort loc group_2 year
replace pop_lag20=pop[_n-2] if loc==loc[_n-2] & group_2==group_2[_n-2]
gen predicted_pop=pop_lag20*growth20

*** Limit to available industries
drop if group_2==300
drop if group_2==709
drop if group_2==1110
drop if group_2==1410
drop if group_2==1907

* Save
sort group_2
save "$temp\city_industry_data_connections_matrices", replace


*******************************************



******* 3. For each industry, merge in connections matrices and sum


foreach i in 310 506 601 702 706 801 802 809 811 1117 1119 1121 1201 1206 1210 1404 1509 1607 1701 1801 1901 1906 2027 {

* load connections matrices values -- DEM and OCC
use "$temp\connections_matrices_DEM_OCC", clear
* limit to the base industry -- so our values focus only in industry i
keep if group_2_1==`i'
drop group_2_1
rename group_2_2 group_2
* group_2 not contains an indentifier for all industries other than i
sort group_2
save "$temp\connections_matrices_DEM_`i'", replace



* load employment data
use "$temp\city_industry_data_connections_matrices", replace

* merge in DEM and OCC connections matrices for industry `i' to all other industries
* Need to use group_2_old for IO merger
sort group_2
merge group_2 using "$temp\connections_matrices_DEM_`i'"
tab _merge
keep if _merge==3
drop _merge


* in logs -- This is the approach used in Hanlon + Miscio
gen ln_pop=ln(pop)
replace ln_pop=0 if ln_pop==.
gen ln_DEM=ln_pop*DEMsim
gen ln_OCC=ln_pop*OCCsim


* in employment levels
gen local_emp_DEM=pop*DEMsim
gen local_emp_OCC=pop*OCCsim

* in levels, with predicted employment (don't worry about this)
gen pred_DEM=predicted_pop*DEMsim
gen pred_OCC=predicted_pop*OCCsim


* Collapse by city year
collapse (sum) local_emp* pred* ln_*, by(loc year)

* identify observation industry
gen group_2=`i'

save "$temp\connections_matrices_controls_`i'_OCC", replace

}


****** append all of the matrices
use "$temp\connections_matrices_controls_310_OCC", clear

foreach i in 506 601 702 706 801 802 809 811 1117 1119 1121 1201 1206 1210 1404 1509 1607 1701 1801 1901 1906 2027  {

append using  "$temp\connections_matrices_controls_`i'_OCC"

}

** save
sort loc group_2 year
save "$root\input_data\prepared_connections_matrices_controls_lag20_OCC", replace




***
